==> orient-0.0.1a0.tar.gz: orient-0.0.1a0/orient/core/event.py <==
from reprlib import recursive_repr
from typing import Optional

from reprit.base import generate_repr
from robust.linear import segments_intersection

from orient.hints import (Coordinate,
                          Point,
                          Segment)


class Event:
    __slots__ = ('is_left_endpoint', 'start', 'complement',
                 'from_left_contour', 'below_from_right_contour_in_out')

    def __init__(self,
                 is_left_endpoint: bool,
                 start: Point,
                 complement: Optional['Event'],
                 from_left_contour: bool,
                 below_from_right_contour_in_out: Optional[bool] = None
                 ) -> None:
        self.is_left_endpoint = is_left_endpoint
        self.start = start
        self.complement = complement
        self.from_left_contour = from_left_contour
        self.below_from_right_contour_in_out = below_from_right_contour_in_out

    __repr__ = recursive_repr()(generate_repr(__init__))

    @property
    def end(self) -> Point:
        return self.complement.start

    @property
    def is_vertical(self) -> bool:
        start_x, _ = self.start
        end_x, _ = self.end
        return start_x == end_x

    @property
    def is_horizontal(self) -> bool:
        _, start_y = self.start
        _, end_y = self.end
        return start_y == end_y

    @property
    def segment(self) -> Segment:
        return self.start, self.end

    def y_at(self, x: Coordinate) -> Coordinate:
        if self.is_vertical or self.is_horizontal:
            _, start_y = self.start
            return start_y
        else:
            start_x, start_y = self.start
            if x == start_x:
                return start_y
            end_x, end_y = self.end
            if x == end_x:
                return end_y
            _, result = segments_intersection(self.segment,
                                              ((x, start_y), (x, end_y)))
            return result

==> orient-0.2.0.tar.gz: orient-0.2.0/orient/core/event.py <==
from enum import (IntEnum,
                  unique)
from reprlib import recursive_repr
from typing import Optional

from reprit.base import generate_repr
from robust.linear import segments_intersection

from orient.hints import (Coordinate,
                          Point,
                          Segment)


@unique
class EdgeKind(IntEnum):
    NORMAL = 0
    NON_CONTRIBUTING = 1
    SAME_TRANSITION = 2
    DIFFERENT_TRANSITION = 3


class Event:
    __slots__ = ('is_left_endpoint', 'start', 'complement',
                 'from_test_contour', 'in_out', 'other_in_out',
                 'edge_kind')

    def __init__(self,
                 is_left_endpoint: bool,
                 start: Point,
                 complement: Optional['Event'],
                 from_test_contour: bool,
                 edge_kind: EdgeKind,
                 in_out: Optional[bool] = None,
                 other_in_out: Optional[bool] = None) -> None:
        self.is_left_endpoint = is_left_endpoint
        self.start = start
        self.complement = complement
        self.from_test_contour = from_test_contour
        self.edge_kind = edge_kind
        self.in_out = in_out
        self.other_in_out = other_in_out

    __repr__ = recursive_repr()(generate_repr(__init__))

    @property
    def end(self) -> Point:
        return self.complement.start

    @property
    def is_vertical(self) -> bool:
        start_x, _ = self.start
        end_x, _ = self.end
        return start_x == end_x

    @property
    def is_horizontal(self) -> bool:
        _, start_y = self.start
        _, end_y = self.end
        return start_y == end_y

    @property
    def in_intersection(self) -> bool:
        edge_kind = self.edge_kind
        return (edge_kind is EdgeKind.NORMAL and not self.other_in_out
                or edge_kind is EdgeKind.SAME_TRANSITION)

    @property
    def segment(self) -> Segment:
        return self.start, self.end

    def y_at(self, x: Coordinate) -> Coordinate:
        if self.is_vertical or self.is_horizontal:
            _, start_y = self.start
            return start_y
        else:
            start_x, start_y = self.start
            if x == start_x:
                return start_y
            end_x, end_y = self.end
            if x == end_x:
                return end_y
            _, result = segments_intersection(self.segment,
                                              ((x, start_y), (x, end_y)))
            return result
